@@ -5,7 +5,8 @@ import fsspec
 from fsspec.core import split_protocol
 from fsspec.registry import get_filesystem_class
 
-from pystac.utils import (is_absolute_href, make_absolute_href)
+from pystac.utils import (is_absolute_href, make_absolute_href,
+                          make_relative_href)
 
 logger = logging.getLogger(__name__)
 
@@ -62,7 +63,7 @@ def move_asset_file_to_item(item,
         else:
             if copy:
 
-                def _op(dry_run=False):
+                def _op1(dry_run=False):
                     logger.info("Copying {} to {}...".format(
                         asset_href, new_asset_href))
                     if not dry_run:
@@ -72,13 +73,13 @@ def move_asset_file_to_item(item,
                             with fsspec.open(new_asset_href, 'wb') as f_dst:
                                 f_dst.write(f_src.read())
 
-                op = _op
+                op = _op1
             else:
                 source_protocol = split_protocol(asset_href)[0]
 
                 if source_protocol == dest_protocol:
 
-                    def _op(dry_run=False):
+                    def _op2(dry_run=False):
                         logger.info("Moving {} to {}...".format(
                             asset_href, new_asset_href))
                         if not dry_run:
@@ -86,10 +87,10 @@ def move_asset_file_to_item(item,
                                              exist_ok=True)
                             fs_dest.move(asset_href, new_asset_href)
 
-                    op = _op
+                    op = _op2
                 else:
 
-                    def _op(dry_run=False):
+                    def _op3(dry_run=False):
                         logger.info("Moving {} to {}...".format(
                             asset_href, new_asset_href))
                         if not dry_run:
@@ -102,7 +103,7 @@ def move_asset_file_to_item(item,
                                     f_dst.write(f_src.read())
                             fs_source.delete(asset_href)
 
-                    op = _op
+                    op = _op3
 
         if op is not None:
             op(dry_run=False)
@@ -112,6 +113,7 @@ def move_asset_file_to_item(item,
 
 def move_assets(item,
                 asset_subdirectory=None,
+                make_hrefs_relative=True,
                 copy=False,
                 ignore_conflicts=False):
     """Moves assets for an item to be alongside that item.
@@ -122,6 +124,8 @@ def move_assets(item,
         asset_subdirectory (str or None): A subdirectory that will be used
             to store the assets. If not supplied, the assets will be moved
             or copied to the same directory as their item.
+        make_assets_relative (bool): If True, will make the asset HREFs relative
+            to the assets. If false, the asset will be an absolute href.
         copy (bool): If False this function will move the asset file; if True,
             the asset file will be copied.
         ignore_conflicts (bool): If the asset destination file already exists,
@@ -147,13 +151,17 @@ def move_assets(item,
             copy=copy,
             ignore_conflicts=ignore_conflicts)
 
-        asset.href = new_asset_href
+        if make_hrefs_relative:
+            asset.href = make_relative_href(new_asset_href, item_href)
+        else:
+            asset.href = new_asset_href
 
     return item
 
 
 def move_all_assets(catalog,
                     asset_subdirectory=None,
+                    make_hrefs_relative=True,
                     copy=False,
                     ignore_conflicts=False):
     """Moves assets in a catalog to be alongside the items that own them.
@@ -164,6 +172,8 @@ def move_all_assets(catalog,
         asset_subdirectory (str or None): A subdirectory that will be used
             to store the assets. If not supplied, the assets will be moved
             or copied to the same directory as their item.
+        make_assets_relative (bool): If True, will make the asset HREFs relative
+            to the assets. If false, the asset will be an absolute href.
         copy (bool): If False this function will move the asset file; if True,
             the asset file will be copied.
         ignore_conflicts (bool): If the asset destination file already exists,
@@ -175,7 +185,8 @@ def move_all_assets(catalog,
     """
 
     for item in catalog.get_all_items():
-        move_assets(item, asset_subdirectory, copy, ignore_conflicts)
+        move_assets(item, asset_subdirectory, make_hrefs_relative, copy,
+                    ignore_conflicts)
 
     return catalog
 
@@ -190,6 +201,6 @@ def copy_catalog(source_catalog,
     catalog.normalize_hrefs(dest_directory)
 
     if copy_assets:
-        catalog = move_all_assets(catalog, copy=True)
+        catalog = move_all_assets(catalog, copy=True, make_hrefs_relative=True)
 
     catalog.save(catalog_type)
